==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/ResourceLocationDataContractArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Resource location data properties.
 * @property city The city or locality where the resource is located.
 * @property countryOrRegion The country or region where the resource is located.
 * @property district The district, state, or province where the resource is located.
 * @property name A canonical name for the geographic or physical location.
 */
public data class ResourceLocationDataContractArgs(
    public val city: Output<String>? = null,
    public val countryOrRegion: Output<String>? = null,
    public val district: Output<String>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs =
        com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs.builder()
            .city(city?.applyValue({ args0 -> args0 }))
            .countryOrRegion(countryOrRegion?.applyValue({ args0 -> args0 }))
            .district(district?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceLocationDataContractArgs].
 */
@PulumiTagMarker
public class ResourceLocationDataContractArgsBuilder internal constructor() {
    private var city: Output<String>? = null

    private var countryOrRegion: Output<String>? = null

    private var district: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value The city or locality where the resource is located.
     */
    @JvmName("nciirixxlonmqhtj")
    public suspend fun city(`value`: Output<String>) {
        this.city = value
    }

    /**
     * @param value The country or region where the resource is located.
     */
    @JvmName("uybpotbpmlkixwva")
    public suspend fun countryOrRegion(`value`: Output<String>) {
        this.countryOrRegion = value
    }

    /**
     * @param value The district, state, or province where the resource is located.
     */
    @JvmName("tubywvffvdbeyjmn")
    public suspend fun district(`value`: Output<String>) {
        this.district = value
    }

    /**
     * @param value A canonical name for the geographic or physical location.
     */
    @JvmName("gmjuakiyfcecjjbu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The city or locality where the resource is located.
     */
    @JvmName("naacjxhlbcqorkic")
    public suspend fun city(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.city = mapped
    }

    /**
     * @param value The country or region where the resource is located.
     */
    @JvmName("fsijddvdylieibyf")
    public suspend fun countryOrRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.countryOrRegion = mapped
    }

    /**
     * @param value The district, state, or province where the resource is located.
     */
    @JvmName("piuxwtxskfoudyym")
    public suspend fun district(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.district = mapped
    }

    /**
     * @param value A canonical name for the geographic or physical location.
     */
    @JvmName("utjavctsmbtdpfah")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ResourceLocationDataContractArgs = ResourceLocationDataContractArgs(
        city = city,
        countryOrRegion = countryOrRegion,
        district = district,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/ResourceLocationDataContractArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Resource location data properties.
 * @property city The city or locality where the resource is located.
 * @property countryOrRegion The country or region where the resource is located.
 * @property district The district, state, or province where the resource is located.
 * @property name A canonical name for the geographic or physical location.
 */
public data class ResourceLocationDataContractArgs(
    public val city: Output<String>? = null,
    public val countryOrRegion: Output<String>? = null,
    public val district: Output<String>? = null,
    public val name: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs =
        com.pulumi.azurenative.apimanagement.inputs.ResourceLocationDataContractArgs.builder()
            .city(city?.applyValue({ args0 -> args0 }))
            .countryOrRegion(countryOrRegion?.applyValue({ args0 -> args0 }))
            .district(district?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceLocationDataContractArgs].
 */
@PulumiTagMarker
public class ResourceLocationDataContractArgsBuilder internal constructor() {
    private var city: Output<String>? = null

    private var countryOrRegion: Output<String>? = null

    private var district: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value The city or locality where the resource is located.
     */
    @JvmName("vjvkkfqbfudynwbe")
    public suspend fun city(`value`: Output<String>) {
        this.city = value
    }

    /**
     * @param value The country or region where the resource is located.
     */
    @JvmName("tmqjwyyahdbpfsff")
    public suspend fun countryOrRegion(`value`: Output<String>) {
        this.countryOrRegion = value
    }

    /**
     * @param value The district, state, or province where the resource is located.
     */
    @JvmName("khdagrkflyoonpxt")
    public suspend fun district(`value`: Output<String>) {
        this.district = value
    }

    /**
     * @param value A canonical name for the geographic or physical location.
     */
    @JvmName("nvqufiybucajurxv")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The city or locality where the resource is located.
     */
    @JvmName("jjutfigygjgeehfj")
    public suspend fun city(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.city = mapped
    }

    /**
     * @param value The country or region where the resource is located.
     */
    @JvmName("smupjfbyedxxpigw")
    public suspend fun countryOrRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.countryOrRegion = mapped
    }

    /**
     * @param value The district, state, or province where the resource is located.
     */
    @JvmName("mvaqvxfcwxrggosh")
    public suspend fun district(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.district = mapped
    }

    /**
     * @param value A canonical name for the geographic or physical location.
     */
    @JvmName("cvtkmnyodmgjglib")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ResourceLocationDataContractArgs = ResourceLocationDataContractArgs(
        city = city,
        countryOrRegion = countryOrRegion,
        district = district,
        name = name ?: throw PulumiNullFieldException("name"),
    )
}
